@@ -27,12 +27,21 @@ sub process {
         if ($parameters_length < $self->{required_parameters_count}) {
             die Exception->new("Exception: ResolveInstance parameters mismatch");
         }
-        my $reference_cache = ReferencesCache->new();
-        my $resolved_reference = $reference_cache->resolve_reference($command);
-        return $resolved_reference;
+        if ($command->{runtime} == Javonet::Sdk::Core::RuntimeLib::get_runtime('Perl')) {
+            my $reference_cache = ReferencesCache->new();
+            my $resolved_reference = $reference_cache->resolve_reference($command);
+            return $resolved_reference;
+        }
+        else {
+            return PerlCommand->new(
+                runtime      => $command->{runtime},
+                command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Reference'),
+                payload      => [ $command->{payload}]
+            );
+        }
     }
     catch ($e){
         return Exception->new($e);
     }
 }
-1;
\ No newline at end of file
+1;
